# coding: utf-8

"""
    3blades API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import sys
import os
import re

# python 2 and python 3 compatibility library
from six import iteritems

from ..configuration import Configuration
from ..api_client import ApiClient


class UsersApi(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        config = Configuration()
        if api_client:
            self.api_client = api_client
        else:
            if not config.api_client:
                config.api_client = ApiClient()
            self.api_client = config.api_client

    def me(self, **kwargs):
        """
        A convenience endpoint that is equivalent to GET /v1/users/profiles/<my user id>/
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.me(callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :return: User
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.me_with_http_info(**kwargs)
        else:
            (data) = self.me_with_http_info(**kwargs)
            return data

    def me_with_http_info(self, **kwargs):
        """
        A convenience endpoint that is equivalent to GET /v1/users/profiles/<my user id>/
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.me_with_http_info(callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :return: User
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = []
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method me" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json', 'text/html'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['jwt']

        return self.api_client.call_api('/v1/me', 'GET',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type='User',
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def user_avatar_delete(self, user, **kwargs):
        """
        Delete avatar
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.user_avatar_delete(user, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str user: User unique identifier expressed as UUID or username. (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.user_avatar_delete_with_http_info(user, **kwargs)
        else:
            (data) = self.user_avatar_delete_with_http_info(user, **kwargs)
            return data

    def user_avatar_delete_with_http_info(self, user, **kwargs):
        """
        Delete avatar
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.user_avatar_delete_with_http_info(user, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str user: User unique identifier expressed as UUID or username. (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['user']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method user_avatar_delete" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'user' is set
        if ('user' not in params) or (params['user'] is None):
            raise ValueError("Missing the required parameter `user` when calling `user_avatar_delete`")


        collection_formats = {}

        path_params = {}
        if 'user' in params:
            path_params['user'] = params['user']

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json', 'text/html'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['jwt']

        return self.api_client.call_api('/v1/users/{user}/avatar/', 'DELETE',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type=None,
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def user_avatar_get(self, user, **kwargs):
        """
        Retrieve user's avatar
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.user_avatar_get(user, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str user: User unique identifier expressed as UUIDor username. (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.user_avatar_get_with_http_info(user, **kwargs)
        else:
            (data) = self.user_avatar_get_with_http_info(user, **kwargs)
            return data

    def user_avatar_get_with_http_info(self, user, **kwargs):
        """
        Retrieve user's avatar
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.user_avatar_get_with_http_info(user, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str user: User unique identifier expressed as UUIDor username. (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['user']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method user_avatar_get" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'user' is set
        if ('user' not in params) or (params['user'] is None):
            raise ValueError("Missing the required parameter `user` when calling `user_avatar_get`")


        collection_formats = {}

        path_params = {}
        if 'user' in params:
            path_params['user'] = params['user']

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json', 'text/html'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['jwt']

        return self.api_client.call_api('/v1/users/{user}/avatar/', 'GET',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type=None,
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def user_avatar_set(self, user, **kwargs):
        """
        Add user avatar
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.user_avatar_set(user, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str user: User unique identifier expressed as UUID or username. (required)
        :return: User
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.user_avatar_set_with_http_info(user, **kwargs)
        else:
            (data) = self.user_avatar_set_with_http_info(user, **kwargs)
            return data

    def user_avatar_set_with_http_info(self, user, **kwargs):
        """
        Add user avatar
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.user_avatar_set_with_http_info(user, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str user: User unique identifier expressed as UUID or username. (required)
        :return: User
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['user']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method user_avatar_set" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'user' is set
        if ('user' not in params) or (params['user'] is None):
            raise ValueError("Missing the required parameter `user` when calling `user_avatar_set`")


        collection_formats = {}

        path_params = {}
        if 'user' in params:
            path_params['user'] = params['user']

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json', 'text/html'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['multipart/form-data'])

        # Authentication setting
        auth_settings = ['jwt']

        return self.api_client.call_api('/v1/users/{user}/avatar/', 'POST',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type='User',
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def user_avatar_update(self, user, **kwargs):
        """
        Update a project file
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.user_avatar_update(user, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str user: User unique identifier expressed as UUID or username. (required)
        :return: User
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.user_avatar_update_with_http_info(user, **kwargs)
        else:
            (data) = self.user_avatar_update_with_http_info(user, **kwargs)
            return data

    def user_avatar_update_with_http_info(self, user, **kwargs):
        """
        Update a project file
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.user_avatar_update_with_http_info(user, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str user: User unique identifier expressed as UUID or username. (required)
        :return: User
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['user']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method user_avatar_update" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'user' is set
        if ('user' not in params) or (params['user'] is None):
            raise ValueError("Missing the required parameter `user` when calling `user_avatar_update`")


        collection_formats = {}

        path_params = {}
        if 'user' in params:
            path_params['user'] = params['user']

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json', 'text/html'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['multipart/form-data'])

        # Authentication setting
        auth_settings = ['jwt']

        return self.api_client.call_api('/v1/users/{user}/avatar/', 'PATCH',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type='User',
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def users_api_key_list(self, user, **kwargs):
        """
        Retrieve account's API key
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.users_api_key_list(user, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str user: User unique identifier expressed as UUID or username. (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.users_api_key_list_with_http_info(user, **kwargs)
        else:
            (data) = self.users_api_key_list_with_http_info(user, **kwargs)
            return data

    def users_api_key_list_with_http_info(self, user, **kwargs):
        """
        Retrieve account's API key
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.users_api_key_list_with_http_info(user, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str user: User unique identifier expressed as UUID or username. (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['user']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method users_api_key_list" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'user' is set
        if ('user' not in params) or (params['user'] is None):
            raise ValueError("Missing the required parameter `user` when calling `users_api_key_list`")


        collection_formats = {}

        path_params = {}
        if 'user' in params:
            path_params['user'] = params['user']

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json', 'text/html'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['jwt']

        return self.api_client.call_api('/v1/users/{user}/api-key/', 'GET',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type=None,
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def users_api_key_reset(self, user, **kwargs):
        """
        Reset a user's API key
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.users_api_key_reset(user, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str user: User unique identifier expressed as UUID or username. (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.users_api_key_reset_with_http_info(user, **kwargs)
        else:
            (data) = self.users_api_key_reset_with_http_info(user, **kwargs)
            return data

    def users_api_key_reset_with_http_info(self, user, **kwargs):
        """
        Reset a user's API key
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.users_api_key_reset_with_http_info(user, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str user: User unique identifier expressed as UUID or username. (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['user']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method users_api_key_reset" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'user' is set
        if ('user' not in params) or (params['user'] is None):
            raise ValueError("Missing the required parameter `user` when calling `users_api_key_reset`")


        collection_formats = {}

        path_params = {}
        if 'user' in params:
            path_params['user'] = params['user']

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json', 'text/html'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['jwt']

        return self.api_client.call_api('/v1/users/{user}/api-key/reset/', 'POST',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type=None,
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def users_create(self, **kwargs):
        """
        Create new user
        Only admin users can create new users. New users have active status by default.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.users_create(callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param UserData user_data:
        :return: User
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.users_create_with_http_info(**kwargs)
        else:
            (data) = self.users_create_with_http_info(**kwargs)
            return data

    def users_create_with_http_info(self, **kwargs):
        """
        Create new user
        Only admin users can create new users. New users have active status by default.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.users_create_with_http_info(callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param UserData user_data:
        :return: User
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['user_data']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method users_create" % key
                )
            params[key] = val
        del params['kwargs']


        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'user_data' in params:
            body_params = params['user_data']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json', 'text/html'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['jwt']

        return self.api_client.call_api('/v1/users/profiles/', 'POST',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type='User',
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def users_delete(self, user, **kwargs):
        """
        Delete a user
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.users_delete(user, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str user: User identifier expressed as UUID or username. (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.users_delete_with_http_info(user, **kwargs)
        else:
            (data) = self.users_delete_with_http_info(user, **kwargs)
            return data

    def users_delete_with_http_info(self, user, **kwargs):
        """
        Delete a user
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.users_delete_with_http_info(user, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str user: User identifier expressed as UUID or username. (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['user']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method users_delete" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'user' is set
        if ('user' not in params) or (params['user'] is None):
            raise ValueError("Missing the required parameter `user` when calling `users_delete`")


        collection_formats = {}

        path_params = {}
        if 'user' in params:
            path_params['user'] = params['user']

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json', 'text/html'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['jwt']

        return self.api_client.call_api('/v1/users/profiles/{user}/', 'DELETE',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type=None,
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def users_emails_create(self, user, **kwargs):
        """
        Create an email address
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.users_emails_create(user, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str user: User unique identifier expressed as UUID or username. (required)
        :param EmailData email_data:
        :return: Email
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.users_emails_create_with_http_info(user, **kwargs)
        else:
            (data) = self.users_emails_create_with_http_info(user, **kwargs)
            return data

    def users_emails_create_with_http_info(self, user, **kwargs):
        """
        Create an email address
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.users_emails_create_with_http_info(user, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str user: User unique identifier expressed as UUID or username. (required)
        :param EmailData email_data:
        :return: Email
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['user', 'email_data']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method users_emails_create" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'user' is set
        if ('user' not in params) or (params['user'] is None):
            raise ValueError("Missing the required parameter `user` when calling `users_emails_create`")


        collection_formats = {}

        path_params = {}
        if 'user' in params:
            path_params['user'] = params['user']

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'email_data' in params:
            body_params = params['email_data']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json', 'text/html'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['jwt']

        return self.api_client.call_api('/v1/users/{user}/emails/', 'POST',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type='Email',
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def users_emails_delete(self, email_id, user, **kwargs):
        """
        Delete an email address
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.users_emails_delete(email_id, user, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str email_id: Email unique identifier expressed as UUID. (required)
        :param str user: User unique identifier expressed as UUID or username. (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.users_emails_delete_with_http_info(email_id, user, **kwargs)
        else:
            (data) = self.users_emails_delete_with_http_info(email_id, user, **kwargs)
            return data

    def users_emails_delete_with_http_info(self, email_id, user, **kwargs):
        """
        Delete an email address
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.users_emails_delete_with_http_info(email_id, user, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str email_id: Email unique identifier expressed as UUID. (required)
        :param str user: User unique identifier expressed as UUID or username. (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['email_id', 'user']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method users_emails_delete" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'email_id' is set
        if ('email_id' not in params) or (params['email_id'] is None):
            raise ValueError("Missing the required parameter `email_id` when calling `users_emails_delete`")
        # verify the required parameter 'user' is set
        if ('user' not in params) or (params['user'] is None):
            raise ValueError("Missing the required parameter `user` when calling `users_emails_delete`")


        collection_formats = {}

        path_params = {}
        if 'email_id' in params:
            path_params['email_id'] = params['email_id']
        if 'user' in params:
            path_params['user'] = params['user']

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json', 'text/html'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['jwt']

        return self.api_client.call_api('/v1/users/{user}/emails/{email_id}/', 'DELETE',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type=None,
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def users_emails_list(self, user, **kwargs):
        """
        Retrieve account email addresses
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.users_emails_list(user, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str user: User unique identifier as expressed as UUID or username. (required)
        :param str limit: Limite when getting email list.
        :param str offset: Offset when getting email list.
        :param str ordering: Ordering when getting email list.
        :return: list[Email]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.users_emails_list_with_http_info(user, **kwargs)
        else:
            (data) = self.users_emails_list_with_http_info(user, **kwargs)
            return data

    def users_emails_list_with_http_info(self, user, **kwargs):
        """
        Retrieve account email addresses
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.users_emails_list_with_http_info(user, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str user: User unique identifier as expressed as UUID or username. (required)
        :param str limit: Limite when getting email list.
        :param str offset: Offset when getting email list.
        :param str ordering: Ordering when getting email list.
        :return: list[Email]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['user', 'limit', 'offset', 'ordering']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method users_emails_list" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'user' is set
        if ('user' not in params) or (params['user'] is None):
            raise ValueError("Missing the required parameter `user` when calling `users_emails_list`")


        collection_formats = {}

        path_params = {}
        if 'user' in params:
            path_params['user'] = params['user']

        query_params = []
        if 'limit' in params:
            query_params.append(('limit', params['limit']))
        if 'offset' in params:
            query_params.append(('offset', params['offset']))
        if 'ordering' in params:
            query_params.append(('ordering', params['ordering']))

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json', 'text/html'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['jwt']

        return self.api_client.call_api('/v1/users/{user}/emails/', 'GET',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type='list[Email]',
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def users_emails_read(self, email_id, user, **kwargs):
        """
        Retrieve a user's email addresses
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.users_emails_read(email_id, user, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str email_id: Email unique identifier expressed as UUID. (required)
        :param str user: User unique identifier expressed as UUID or username. (required)
        :return: Email
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.users_emails_read_with_http_info(email_id, user, **kwargs)
        else:
            (data) = self.users_emails_read_with_http_info(email_id, user, **kwargs)
            return data

    def users_emails_read_with_http_info(self, email_id, user, **kwargs):
        """
        Retrieve a user's email addresses
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.users_emails_read_with_http_info(email_id, user, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str email_id: Email unique identifier expressed as UUID. (required)
        :param str user: User unique identifier expressed as UUID or username. (required)
        :return: Email
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['email_id', 'user']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method users_emails_read" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'email_id' is set
        if ('email_id' not in params) or (params['email_id'] is None):
            raise ValueError("Missing the required parameter `email_id` when calling `users_emails_read`")
        # verify the required parameter 'user' is set
        if ('user' not in params) or (params['user'] is None):
            raise ValueError("Missing the required parameter `user` when calling `users_emails_read`")


        collection_formats = {}

        path_params = {}
        if 'email_id' in params:
            path_params['email_id'] = params['email_id']
        if 'user' in params:
            path_params['user'] = params['user']

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json', 'text/html'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['jwt']

        return self.api_client.call_api('/v1/users/{user}/emails/{email_id}/', 'GET',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type='Email',
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def users_emails_replace(self, email_id, user, **kwargs):
        """
        Replace an email address
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.users_emails_replace(email_id, user, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str email_id: Email unique identifier expressed as UUID. (required)
        :param str user: User unique identifier expressed as UUID or username. (required)
        :param EmailData email_data:
        :return: Email
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.users_emails_replace_with_http_info(email_id, user, **kwargs)
        else:
            (data) = self.users_emails_replace_with_http_info(email_id, user, **kwargs)
            return data

    def users_emails_replace_with_http_info(self, email_id, user, **kwargs):
        """
        Replace an email address
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.users_emails_replace_with_http_info(email_id, user, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str email_id: Email unique identifier expressed as UUID. (required)
        :param str user: User unique identifier expressed as UUID or username. (required)
        :param EmailData email_data:
        :return: Email
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['email_id', 'user', 'email_data']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method users_emails_replace" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'email_id' is set
        if ('email_id' not in params) or (params['email_id'] is None):
            raise ValueError("Missing the required parameter `email_id` when calling `users_emails_replace`")
        # verify the required parameter 'user' is set
        if ('user' not in params) or (params['user'] is None):
            raise ValueError("Missing the required parameter `user` when calling `users_emails_replace`")


        collection_formats = {}

        path_params = {}
        if 'email_id' in params:
            path_params['email_id'] = params['email_id']
        if 'user' in params:
            path_params['user'] = params['user']

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'email_data' in params:
            body_params = params['email_data']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json', 'text/html'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['jwt']

        return self.api_client.call_api('/v1/users/{user}/emails/{email_id}/', 'PUT',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type='Email',
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def users_emails_update(self, email_id, user, **kwargs):
        """
        Update an email address
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.users_emails_update(email_id, user, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str email_id: Email unique identifier expressed as UUID. (required)
        :param str user: User unique identifier expressed as UUID or username. (required)
        :param EmailData email_data:
        :return: Email
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.users_emails_update_with_http_info(email_id, user, **kwargs)
        else:
            (data) = self.users_emails_update_with_http_info(email_id, user, **kwargs)
            return data

    def users_emails_update_with_http_info(self, email_id, user, **kwargs):
        """
        Update an email address
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.users_emails_update_with_http_info(email_id, user, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str email_id: Email unique identifier expressed as UUID. (required)
        :param str user: User unique identifier expressed as UUID or username. (required)
        :param EmailData email_data:
        :return: Email
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['email_id', 'user', 'email_data']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method users_emails_update" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'email_id' is set
        if ('email_id' not in params) or (params['email_id'] is None):
            raise ValueError("Missing the required parameter `email_id` when calling `users_emails_update`")
        # verify the required parameter 'user' is set
        if ('user' not in params) or (params['user'] is None):
            raise ValueError("Missing the required parameter `user` when calling `users_emails_update`")


        collection_formats = {}

        path_params = {}
        if 'email_id' in params:
            path_params['email_id'] = params['email_id']
        if 'user' in params:
            path_params['user'] = params['user']

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'email_data' in params:
            body_params = params['email_data']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json', 'text/html'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['jwt']

        return self.api_client.call_api('/v1/users/{user}/emails/{email_id}/', 'PATCH',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type='Email',
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def users_list(self, **kwargs):
        """
        Get user list
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.users_list(callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str limit: Limit user list.
        :param str offset: Offset when getting users.
        :param str username: User username.
        :param str email: User email.
        :param str ordering: Ordering when getting users.
        :return: list[User]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.users_list_with_http_info(**kwargs)
        else:
            (data) = self.users_list_with_http_info(**kwargs)
            return data

    def users_list_with_http_info(self, **kwargs):
        """
        Get user list
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.users_list_with_http_info(callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str limit: Limit user list.
        :param str offset: Offset when getting users.
        :param str username: User username.
        :param str email: User email.
        :param str ordering: Ordering when getting users.
        :return: list[User]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['limit', 'offset', 'username', 'email', 'ordering']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method users_list" % key
                )
            params[key] = val
        del params['kwargs']


        collection_formats = {}

        path_params = {}

        query_params = []
        if 'limit' in params:
            query_params.append(('limit', params['limit']))
        if 'offset' in params:
            query_params.append(('offset', params['offset']))
        if 'username' in params:
            query_params.append(('username', params['username']))
        if 'email' in params:
            query_params.append(('email', params['email']))
        if 'ordering' in params:
            query_params.append(('ordering', params['ordering']))

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json', 'text/html'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['jwt']

        return self.api_client.call_api('/v1/users/profiles/', 'GET',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type='list[User]',
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def users_read(self, user, **kwargs):
        """
        Retrieve a user
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.users_read(user, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str user: Unique identifier expressed as UUID or username. (required)
        :return: User
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.users_read_with_http_info(user, **kwargs)
        else:
            (data) = self.users_read_with_http_info(user, **kwargs)
            return data

    def users_read_with_http_info(self, user, **kwargs):
        """
        Retrieve a user
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.users_read_with_http_info(user, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str user: Unique identifier expressed as UUID or username. (required)
        :return: User
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['user']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method users_read" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'user' is set
        if ('user' not in params) or (params['user'] is None):
            raise ValueError("Missing the required parameter `user` when calling `users_read`")


        collection_formats = {}

        path_params = {}
        if 'user' in params:
            path_params['user'] = params['user']

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json', 'text/html'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['jwt']

        return self.api_client.call_api('/v1/users/profiles/{user}/', 'GET',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type='User',
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def users_ssh_key_list(self, user, **kwargs):
        """
        Retrieve an SSH key
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.users_ssh_key_list(user, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str user: User unique identifier expressed as UUID or username. (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.users_ssh_key_list_with_http_info(user, **kwargs)
        else:
            (data) = self.users_ssh_key_list_with_http_info(user, **kwargs)
            return data

    def users_ssh_key_list_with_http_info(self, user, **kwargs):
        """
        Retrieve an SSH key
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.users_ssh_key_list_with_http_info(user, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str user: User unique identifier expressed as UUID or username. (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['user']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method users_ssh_key_list" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'user' is set
        if ('user' not in params) or (params['user'] is None):
            raise ValueError("Missing the required parameter `user` when calling `users_ssh_key_list`")


        collection_formats = {}

        path_params = {}
        if 'user' in params:
            path_params['user'] = params['user']

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json', 'text/html'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['jwt']

        return self.api_client.call_api('/v1/users/{user}/ssh-key/', 'GET',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type=None,
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def users_ssh_key_reset(self, user, **kwargs):
        """
        Recreate an SSH key
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.users_ssh_key_reset(user, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str user: User unique identifier expressed as UUID or username. (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.users_ssh_key_reset_with_http_info(user, **kwargs)
        else:
            (data) = self.users_ssh_key_reset_with_http_info(user, **kwargs)
            return data

    def users_ssh_key_reset_with_http_info(self, user, **kwargs):
        """
        Recreate an SSH key
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.users_ssh_key_reset_with_http_info(user, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str user: User unique identifier expressed as UUID or username. (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['user']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method users_ssh_key_reset" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'user' is set
        if ('user' not in params) or (params['user'] is None):
            raise ValueError("Missing the required parameter `user` when calling `users_ssh_key_reset`")


        collection_formats = {}

        path_params = {}
        if 'user' in params:
            path_params['user'] = params['user']

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json', 'text/html'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['jwt']

        return self.api_client.call_api('/v1/users/{user}/ssh-key/reset/', 'POST',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type=None,
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def users_update(self, user, **kwargs):
        """
        Update a user
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.users_update(user, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str user: User unique identifier expressed as UUID or username. (required)
        :param UserData user_data:
        :return: User
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.users_update_with_http_info(user, **kwargs)
        else:
            (data) = self.users_update_with_http_info(user, **kwargs)
            return data

    def users_update_with_http_info(self, user, **kwargs):
        """
        Update a user
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.users_update_with_http_info(user, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str user: User unique identifier expressed as UUID or username. (required)
        :param UserData user_data:
        :return: User
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['user', 'user_data']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method users_update" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'user' is set
        if ('user' not in params) or (params['user'] is None):
            raise ValueError("Missing the required parameter `user` when calling `users_update`")


        collection_formats = {}

        path_params = {}
        if 'user' in params:
            path_params['user'] = params['user']

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'user_data' in params:
            body_params = params['user_data']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json', 'text/html'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['jwt']

        return self.api_client.call_api('/v1/users/profiles/{user}/', 'PATCH',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type='User',
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)



# coding: utf-8

"""
    3blades API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import os
import sys
import unittest

import swagger_client
from swagger_client.rest import ApiException
from swagger_client.apis.notifications_api import NotificationsApi


class TestNotificationsApi(unittest.TestCase):
    """ NotificationsApi unit test stubs """

    def setUp(self):
        self.api = swagger_client.apis.notifications_api.NotificationsApi()

    def tearDown(self):
        pass

    def test_notification_read(self):
        """
        Test case for notification_read

        Retrieve a specific notification.
        """
        pass

    def test_notification_settings_create(self):
        """
        Test case for notification_settings_create

        Create global notification settings
        """
        pass

    def test_notification_settings_entity_create(self):
        """
        Test case for notification_settings_entity_create

        Create global notification settings
        """
        pass

    def test_notification_settings_entity_read(self):
        """
        Test case for notification_settings_entity_read

        Retrieve global notification settings for the authenticated user
        """
        pass

    def test_notification_settings_entity_update(self):
        """
        Test case for notification_settings_entity_update

        Modify global notification settings.
        """
        pass

    def test_notification_settings_read(self):
        """
        Test case for notification_settings_read

        Retrieve global notification settings for the authenticated user
        """
        pass

    def test_notification_settings_update(self):
        """
        Test case for notification_settings_update

        Modify global notification settings.
        """
        pass

    def test_notification_update(self):
        """
        Test case for notification_update

        Mark a specific notification as either read or unread.
        """
        pass

    def test_notifications_list(self):
        """
        Test case for notifications_list

        Get notifications of all types and entities for the authenticated user.
        """
        pass

    def test_notifications_list_entity(self):
        """
        Test case for notifications_list_entity

        Get notifications of all types and entities for the authenticated user.
        """
        pass

    def test_notifications_update_entity_list(self):
        """
        Test case for notifications_update_entity_list

        Mark a list of notifications as either read or unread.
        """
        pass

    def test_notifications_update_list(self):
        """
        Test case for notifications_update_list

        Mark a list of notifications as either read or unread.
        """
        pass


if __name__ == '__main__':
    unittest.main()



from __future__ import absolute_import

# import apis into api package
from .auth_api import AuthApi
from .billing_api import BillingApi
from .deployments_api import DeploymentsApi
from .hosts_api import HostsApi
from .notifications_api import NotificationsApi
from .projects_api import ProjectsApi
from .search_api import SearchApi
from .servers_api import ServersApi
from .users_api import UsersApi



# coding: utf-8

"""
    3blades API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class CardError(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'non_field_errors': 'list[str]',
        'name': 'list[str]',
        'address_line1': 'list[str]',
        'address_line2': 'list[str]',
        'address_city': 'list[str]',
        'address_state': 'list[str]',
        'address_zip': 'list[str]',
        'address_country': 'list[str]',
        'exp_month': 'list[str]',
        'exp_year': 'list[str]',
        'token': 'list[str]',
        'id': 'list[str]',
        'customer': 'list[str]',
        'address_line1_check': 'list[str]',
        'address_zip_check': 'list[str]',
        'brand': 'list[str]',
        'cvc_check': 'list[str]',
        'last4': 'list[str]',
        'fingerprint': 'list[str]',
        'funding': 'list[str]',
        'stripe_id': 'list[str]',
        'created': 'list[str]'
    }

    attribute_map = {
        'non_field_errors': 'non_field_errors',
        'name': 'name',
        'address_line1': 'address_line1',
        'address_line2': 'address_line2',
        'address_city': 'address_city',
        'address_state': 'address_state',
        'address_zip': 'address_zip',
        'address_country': 'address_country',
        'exp_month': 'exp_month',
        'exp_year': 'exp_year',
        'token': 'token',
        'id': 'id',
        'customer': 'customer',
        'address_line1_check': 'address_line1_check',
        'address_zip_check': 'address_zip_check',
        'brand': 'brand',
        'cvc_check': 'cvc_check',
        'last4': 'last4',
        'fingerprint': 'fingerprint',
        'funding': 'funding',
        'stripe_id': 'stripe_id',
        'created': 'created'
    }

    def __init__(self, non_field_errors=None, name=None, address_line1=None, address_line2=None, address_city=None, address_state=None, address_zip=None, address_country=None, exp_month=None, exp_year=None, token=None, id=None, customer=None, address_line1_check=None, address_zip_check=None, brand=None, cvc_check=None, last4=None, fingerprint=None, funding=None, stripe_id=None, created=None):
        """
        CardError - a model defined in Swagger
        """

        self._non_field_errors = None
        self._name = None
        self._address_line1 = None
        self._address_line2 = None
        self._address_city = None
        self._address_state = None
        self._address_zip = None
        self._address_country = None
        self._exp_month = None
        self._exp_year = None
        self._token = None
        self._id = None
        self._customer = None
        self._address_line1_check = None
        self._address_zip_check = None
        self._brand = None
        self._cvc_check = None
        self._last4 = None
        self._fingerprint = None
        self._funding = None
        self._stripe_id = None
        self._created = None

        if non_field_errors is not None:
          self.non_field_errors = non_field_errors
        if name is not None:
          self.name = name
        if address_line1 is not None:
          self.address_line1 = address_line1
        if address_line2 is not None:
          self.address_line2 = address_line2
        if address_city is not None:
          self.address_city = address_city
        if address_state is not None:
          self.address_state = address_state
        if address_zip is not None:
          self.address_zip = address_zip
        if address_country is not None:
          self.address_country = address_country
        if exp_month is not None:
          self.exp_month = exp_month
        if exp_year is not None:
          self.exp_year = exp_year
        if token is not None:
          self.token = token
        if id is not None:
          self.id = id
        if customer is not None:
          self.customer = customer
        if address_line1_check is not None:
          self.address_line1_check = address_line1_check
        if address_zip_check is not None:
          self.address_zip_check = address_zip_check
        if brand is not None:
          self.brand = brand
        if cvc_check is not None:
          self.cvc_check = cvc_check
        if last4 is not None:
          self.last4 = last4
        if fingerprint is not None:
          self.fingerprint = fingerprint
        if funding is not None:
          self.funding = funding
        if stripe_id is not None:
          self.stripe_id = stripe_id
        if created is not None:
          self.created = created

    @property
    def non_field_errors(self):
        """
        Gets the non_field_errors of this CardError.
        Errors not connected to any field

        :return: The non_field_errors of this CardError.
        :rtype: list[str]
        """
        return self._non_field_errors

    @non_field_errors.setter
    def non_field_errors(self, non_field_errors):
        """
        Sets the non_field_errors of this CardError.
        Errors not connected to any field

        :param non_field_errors: The non_field_errors of this CardError.
        :type: list[str]
        """

        self._non_field_errors = non_field_errors

    @property
    def name(self):
        """
        Gets the name of this CardError.
        name field errors

        :return: The name of this CardError.
        :rtype: list[str]
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this CardError.
        name field errors

        :param name: The name of this CardError.
        :type: list[str]
        """

        self._name = name

    @property
    def address_line1(self):
        """
        Gets the address_line1 of this CardError.
        address_line1 field errors

        :return: The address_line1 of this CardError.
        :rtype: list[str]
        """
        return self._address_line1

    @address_line1.setter
    def address_line1(self, address_line1):
        """
        Sets the address_line1 of this CardError.
        address_line1 field errors

        :param address_line1: The address_line1 of this CardError.
        :type: list[str]
        """

        self._address_line1 = address_line1

    @property
    def address_line2(self):
        """
        Gets the address_line2 of this CardError.
        address_line2 field errors

        :return: The address_line2 of this CardError.
        :rtype: list[str]
        """
        return self._address_line2

    @address_line2.setter
    def address_line2(self, address_line2):
        """
        Sets the address_line2 of this CardError.
        address_line2 field errors

        :param address_line2: The address_line2 of this CardError.
        :type: list[str]
        """

        self._address_line2 = address_line2

    @property
    def address_city(self):
        """
        Gets the address_city of this CardError.
        address_city field errors

        :return: The address_city of this CardError.
        :rtype: list[str]
        """
        return self._address_city

    @address_city.setter
    def address_city(self, address_city):
        """
        Sets the address_city of this CardError.
        address_city field errors

        :param address_city: The address_city of this CardError.
        :type: list[str]
        """

        self._address_city = address_city

    @property
    def address_state(self):
        """
        Gets the address_state of this CardError.
        address_state field errors

        :return: The address_state of this CardError.
        :rtype: list[str]
        """
        return self._address_state

    @address_state.setter
    def address_state(self, address_state):
        """
        Sets the address_state of this CardError.
        address_state field errors

        :param address_state: The address_state of this CardError.
        :type: list[str]
        """

        self._address_state = address_state

    @property
    def address_zip(self):
        """
        Gets the address_zip of this CardError.
        address_zip field errors

        :return: The address_zip of this CardError.
        :rtype: list[str]
        """
        return self._address_zip

    @address_zip.setter
    def address_zip(self, address_zip):
        """
        Sets the address_zip of this CardError.
        address_zip field errors

        :param address_zip: The address_zip of this CardError.
        :type: list[str]
        """

        self._address_zip = address_zip

    @property
    def address_country(self):
        """
        Gets the address_country of this CardError.
        address_country field errors

        :return: The address_country of this CardError.
        :rtype: list[str]
        """
        return self._address_country

    @address_country.setter
    def address_country(self, address_country):
        """
        Sets the address_country of this CardError.
        address_country field errors

        :param address_country: The address_country of this CardError.
        :type: list[str]
        """

        self._address_country = address_country

    @property
    def exp_month(self):
        """
        Gets the exp_month of this CardError.
        exp_month field errors

        :return: The exp_month of this CardError.
        :rtype: list[str]
        """
        return self._exp_month

    @exp_month.setter
    def exp_month(self, exp_month):
        """
        Sets the exp_month of this CardError.
        exp_month field errors

        :param exp_month: The exp_month of this CardError.
        :type: list[str]
        """

        self._exp_month = exp_month

    @property
    def exp_year(self):
        """
        Gets the exp_year of this CardError.
        exp_year field errors

        :return: The exp_year of this CardError.
        :rtype: list[str]
        """
        return self._exp_year

    @exp_year.setter
    def exp_year(self, exp_year):
        """
        Sets the exp_year of this CardError.
        exp_year field errors

        :param exp_year: The exp_year of this CardError.
        :type: list[str]
        """

        self._exp_year = exp_year

    @property
    def token(self):
        """
        Gets the token of this CardError.
        token field errors

        :return: The token of this CardError.
        :rtype: list[str]
        """
        return self._token

    @token.setter
    def token(self, token):
        """
        Sets the token of this CardError.
        token field errors

        :param token: The token of this CardError.
        :type: list[str]
        """

        self._token = token

    @property
    def id(self):
        """
        Gets the id of this CardError.
        id field errors

        :return: The id of this CardError.
        :rtype: list[str]
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this CardError.
        id field errors

        :param id: The id of this CardError.
        :type: list[str]
        """

        self._id = id

    @property
    def customer(self):
        """
        Gets the customer of this CardError.
        customer field errors

        :return: The customer of this CardError.
        :rtype: list[str]
        """
        return self._customer

    @customer.setter
    def customer(self, customer):
        """
        Sets the customer of this CardError.
        customer field errors

        :param customer: The customer of this CardError.
        :type: list[str]
        """

        self._customer = customer

    @property
    def address_line1_check(self):
        """
        Gets the address_line1_check of this CardError.
        address_line1_check field errors

        :return: The address_line1_check of this CardError.
        :rtype: list[str]
        """
        return self._address_line1_check

    @address_line1_check.setter
    def address_line1_check(self, address_line1_check):
        """
        Sets the address_line1_check of this CardError.
        address_line1_check field errors

        :param address_line1_check: The address_line1_check of this CardError.
        :type: list[str]
        """

        self._address_line1_check = address_line1_check

    @property
    def address_zip_check(self):
        """
        Gets the address_zip_check of this CardError.
        address_zip_check field errors

        :return: The address_zip_check of this CardError.
        :rtype: list[str]
        """
        return self._address_zip_check

    @address_zip_check.setter
    def address_zip_check(self, address_zip_check):
        """
        Sets the address_zip_check of this CardError.
        address_zip_check field errors

        :param address_zip_check: The address_zip_check of this CardError.
        :type: list[str]
        """

        self._address_zip_check = address_zip_check

    @property
    def brand(self):
        """
        Gets the brand of this CardError.
        brand field errors

        :return: The brand of this CardError.
        :rtype: list[str]
        """
        return self._brand

    @brand.setter
    def brand(self, brand):
        """
        Sets the brand of this CardError.
        brand field errors

        :param brand: The brand of this CardError.
        :type: list[str]
        """

        self._brand = brand

    @property
    def cvc_check(self):
        """
        Gets the cvc_check of this CardError.
        cvc_check field errors

        :return: The cvc_check of this CardError.
        :rtype: list[str]
        """
        return self._cvc_check

    @cvc_check.setter
    def cvc_check(self, cvc_check):
        """
        Sets the cvc_check of this CardError.
        cvc_check field errors

        :param cvc_check: The cvc_check of this CardError.
        :type: list[str]
        """

        self._cvc_check = cvc_check

    @property
    def last4(self):
        """
        Gets the last4 of this CardError.
        last4 field errors

        :return: The last4 of this CardError.
        :rtype: list[str]
        """
        return self._last4

    @last4.setter
    def last4(self, last4):
        """
        Sets the last4 of this CardError.
        last4 field errors

        :param last4: The last4 of this CardError.
        :type: list[str]
        """

        self._last4 = last4

    @property
    def fingerprint(self):
        """
        Gets the fingerprint of this CardError.
        fingerprint field errors

        :return: The fingerprint of this CardError.
        :rtype: list[str]
        """
        return self._fingerprint

    @fingerprint.setter
    def fingerprint(self, fingerprint):
        """
        Sets the fingerprint of this CardError.
        fingerprint field errors

        :param fingerprint: The fingerprint of this CardError.
        :type: list[str]
        """

        self._fingerprint = fingerprint

    @property
    def funding(self):
        """
        Gets the funding of this CardError.
        funding field errors

        :return: The funding of this CardError.
        :rtype: list[str]
        """
        return self._funding

    @funding.setter
    def funding(self, funding):
        """
        Sets the funding of this CardError.
        funding field errors

        :param funding: The funding of this CardError.
        :type: list[str]
        """

        self._funding = funding

    @property
    def stripe_id(self):
        """
        Gets the stripe_id of this CardError.
        stripe_id field errors

        :return: The stripe_id of this CardError.
        :rtype: list[str]
        """
        return self._stripe_id

    @stripe_id.setter
    def stripe_id(self, stripe_id):
        """
        Sets the stripe_id of this CardError.
        stripe_id field errors

        :param stripe_id: The stripe_id of this CardError.
        :type: list[str]
        """

        self._stripe_id = stripe_id

    @property
    def created(self):
        """
        Gets the created of this CardError.
        created field errors

        :return: The created of this CardError.
        :rtype: list[str]
        """
        return self._created

    @created.setter
    def created(self, created):
        """
        Sets the created of this CardError.
        created field errors

        :param created: The created of this CardError.
        :type: list[str]
        """

        self._created = created

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, CardError):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other





class DeploymentConfig(object):
    swagger_types = {
        'handler': "str",
        'files': "list",
        'endpoint': "str",
        'resource_id': "str",
        'rest_api_id': "str",
        'function_arn': "str"
    }

    attribute_map = {
        'handler': 'handler',
        'files': 'files',
        'endpoint': 'endpoint',
        'resource_id': 'resource_id',
        'rest_api_id': 'rest_api_id',
        'function_arn': 'function_arn'
    }

    def __init__(self, handler=None, files=None, endpoint=None, resource_id=None, rest_api_id=None, function_arn=None):
        self._handler = None
        self._files = None
        self._endpoint = None
        self._resource_id = None
        self._rest_api_id = None
        self._function_arn = None

        if handler is not None:
            self.handler = handler

        if files is not None:
            self.files = files

        if endpoint is not None:
            self.endpoint = endpoint

        if resource_id is not None:
            self.resource_id = resource_id

        if rest_api_id is not None:
            self.rest_api_id = None

        if function_arn is not None:
            self.function_arn = function_arn

    @property
    def handler(self):
        return self._handler

    @handler.setter
    def handler(self, handler):
        self._handler = handler

    @property
    def files(self):
        return self._files

    @files.setter
    def files(self, files):
        self._files = files

    @property
    def endpoint(self):
        return self._endpoint

    @endpoint.setter
    def endpoint(self, endpoint):
        self._endpoint = endpoint

    @property
    def resource_id(self):
        return self._resource_id

    @resource_id.setter
    def resource_id(self, resource_id):
        self._resource_id = resource_id

    @property
    def rest_api_id(self):
        return self._rest_api_id

    @rest_api_id.setter
    def rest_api_id(self, rest_api_id):
        self._rest_api_id = rest_api_id

    @property
    def function_arn(self):
        return self._function_arn

    @function_arn.setter
    def function_arn(self, function_arn):
        self._function_arn = function_arn



# coding: utf-8

import sys
from setuptools import setup, find_packages

NAME = "tbs-sdk"
VERSION = "0.0.7"
# To install the library, run the following
#
# python setup.py install
#
# prerequisite: setuptools
# http://pypi.python.org/pypi/setuptools

REQUIRES = ["urllib3 >= 1.15", "six >= 1.10", "certifi", "python-dateutil"]

setup(
    name=NAME,
    version=VERSION,
    description="3blades API",
    author_email="jgriebel@3blades.io",
    url="https://github.com/3Blades/python-sdk",
    download_url=f'https://github.com/3Blades/python-sdk/archive/{VERSION}.tar.gz',
    keywords=["3blades API", "Data Science"],
    install_requires=REQUIRES,
    packages=find_packages(),
    include_package_data=True,
)



# coding: utf-8

"""
    3blades API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import sys
import os
import re

# python 2 and python 3 compatibility library
from six import iteritems

from ..configuration import Configuration
from ..api_client import ApiClient


class NotificationsApi(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        config = Configuration()
        if api_client:
            self.api_client = api_client
        else:
            if not config.api_client:
                config.api_client = ApiClient()
            self.api_client = config.api_client

    def notification_read(self, namespace, notification_id, **kwargs):
        """
        Retrieve a specific notification.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.notification_read(namespace, notification_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str namespace: User or team data. (required)
        :param str notification_id: Notification UUID. (required)
        :return: Notification
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.notification_read_with_http_info(namespace, notification_id, **kwargs)
        else:
            (data) = self.notification_read_with_http_info(namespace, notification_id, **kwargs)
            return data

    def notification_read_with_http_info(self, namespace, notification_id, **kwargs):
        """
        Retrieve a specific notification.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.notification_read_with_http_info(namespace, notification_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str namespace: User or team data. (required)
        :param str notification_id: Notification UUID. (required)
        :return: Notification
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['namespace', 'notification_id']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method notification_read" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'namespace' is set
        if ('namespace' not in params) or (params['namespace'] is None):
            raise ValueError("Missing the required parameter `namespace` when calling `notification_read`")
        # verify the required parameter 'notification_id' is set
        if ('notification_id' not in params) or (params['notification_id'] is None):
            raise ValueError("Missing the required parameter `notification_id` when calling `notification_read`")


        collection_formats = {}

        path_params = {}
        if 'namespace' in params:
            path_params['namespace'] = params['namespace']
        if 'notification_id' in params:
            path_params['notification_id'] = params['notification_id']

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json', 'text/html'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['jwt']

        return self.api_client.call_api('/v1/{namespace}/notifications/{notification_id}', 'GET',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type='Notification',
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def notification_settings_create(self, namespace, notification_settings_data, **kwargs):
        """
        Create global notification settings
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.notification_settings_create(namespace, notification_settings_data, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str namespace: User or team name. (required)
        :param NotificationSettingsData notification_settings_data: (required)
        :return: NotificationSettings
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.notification_settings_create_with_http_info(namespace, notification_settings_data, **kwargs)
        else:
            (data) = self.notification_settings_create_with_http_info(namespace, notification_settings_data, **kwargs)
            return data

    def notification_settings_create_with_http_info(self, namespace, notification_settings_data, **kwargs):
        """
        Create global notification settings
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.notification_settings_create_with_http_info(namespace, notification_settings_data, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str namespace: User or team name. (required)
        :param NotificationSettingsData notification_settings_data: (required)
        :return: NotificationSettings
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['namespace', 'notification_settings_data']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method notification_settings_create" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'namespace' is set
        if ('namespace' not in params) or (params['namespace'] is None):
            raise ValueError("Missing the required parameter `namespace` when calling `notification_settings_create`")
        # verify the required parameter 'notification_settings_data' is set
        if ('notification_settings_data' not in params) or (params['notification_settings_data'] is None):
            raise ValueError("Missing the required parameter `notification_settings_data` when calling `notification_settings_create`")


        collection_formats = {}

        path_params = {}
        if 'namespace' in params:
            path_params['namespace'] = params['namespace']

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'notification_settings_data' in params:
            body_params = params['notification_settings_data']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json', 'text/html'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['jwt']

        return self.api_client.call_api('/v1/{namespace}/notifications/settings/', 'POST',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type='NotificationSettings',
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def notification_settings_entity_create(self, namespace, entity, **kwargs):
        """
        Create global notification settings
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.notification_settings_entity_create(namespace, entity, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str namespace: User or team name. (required)
        :param str entity: Entity whose settings should be retrieved. (required)
        :param NotificationSettingsData notification_settings_data:
        :return: NotificationSettings
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.notification_settings_entity_create_with_http_info(namespace, entity, **kwargs)
        else:
            (data) = self.notification_settings_entity_create_with_http_info(namespace, entity, **kwargs)
            return data

    def notification_settings_entity_create_with_http_info(self, namespace, entity, **kwargs):
        """
        Create global notification settings
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.notification_settings_entity_create_with_http_info(namespace, entity, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str namespace: User or team name. (required)
        :param str entity: Entity whose settings should be retrieved. (required)
        :param NotificationSettingsData notification_settings_data:
        :return: NotificationSettings
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['namespace', 'entity', 'notification_settings_data']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method notification_settings_entity_create" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'namespace' is set
        if ('namespace' not in params) or (params['namespace'] is None):
            raise ValueError("Missing the required parameter `namespace` when calling `notification_settings_entity_create`")
        # verify the required parameter 'entity' is set
        if ('entity' not in params) or (params['entity'] is None):
            raise ValueError("Missing the required parameter `entity` when calling `notification_settings_entity_create`")


        collection_formats = {}

        path_params = {}
        if 'namespace' in params:
            path_params['namespace'] = params['namespace']
        if 'entity' in params:
            path_params['entity'] = params['entity']

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'notification_settings_data' in params:
            body_params = params['notification_settings_data']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json', 'text/html'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['jwt']

        return self.api_client.call_api('/v1/{namespace}/notifications/settings/entity/{entity}', 'POST',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type='NotificationSettings',
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def notification_settings_entity_read(self, namespace, entity, **kwargs):
        """
        Retrieve global notification settings for the authenticated user
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.notification_settings_entity_read(namespace, entity, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str namespace: User or team data. (required)
        :param str entity: Entity whose settings should be retrieved. (required)
        :return: list[NotificationSettings]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.notification_settings_entity_read_with_http_info(namespace, entity, **kwargs)
        else:
            (data) = self.notification_settings_entity_read_with_http_info(namespace, entity, **kwargs)
            return data

    def notification_settings_entity_read_with_http_info(self, namespace, entity, **kwargs):
        """
        Retrieve global notification settings for the authenticated user
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.notification_settings_entity_read_with_http_info(namespace, entity, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str namespace: User or team data. (required)
        :param str entity: Entity whose settings should be retrieved. (required)
        :return: list[NotificationSettings]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['namespace', 'entity']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method notification_settings_entity_read" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'namespace' is set
        if ('namespace' not in params) or (params['namespace'] is None):
            raise ValueError("Missing the required parameter `namespace` when calling `notification_settings_entity_read`")
        # verify the required parameter 'entity' is set
        if ('entity' not in params) or (params['entity'] is None):
            raise ValueError("Missing the required parameter `entity` when calling `notification_settings_entity_read`")


        collection_formats = {}

        path_params = {}
        if 'namespace' in params:
            path_params['namespace'] = params['namespace']
        if 'entity' in params:
            path_params['entity'] = params['entity']

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json', 'text/html'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['jwt']

        return self.api_client.call_api('/v1/{namespace}/notifications/settings/entity/{entity}', 'GET',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type='list[NotificationSettings]',
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def notification_settings_entity_update(self, namespace, entity, **kwargs):
        """
        Modify global notification settings.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.notification_settings_entity_update(namespace, entity, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str namespace: User or team name. (required)
        :param str entity: Entity whose settings should be retrieved. (required)
        :param NotificationSettingsData notification_settings_data:
        :return: NotificationSettings
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.notification_settings_entity_update_with_http_info(namespace, entity, **kwargs)
        else:
            (data) = self.notification_settings_entity_update_with_http_info(namespace, entity, **kwargs)
            return data

    def notification_settings_entity_update_with_http_info(self, namespace, entity, **kwargs):
        """
        Modify global notification settings.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.notification_settings_entity_update_with_http_info(namespace, entity, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str namespace: User or team name. (required)
        :param str entity: Entity whose settings should be retrieved. (required)
        :param NotificationSettingsData notification_settings_data:
        :return: NotificationSettings
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['namespace', 'entity', 'notification_settings_data']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method notification_settings_entity_update" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'namespace' is set
        if ('namespace' not in params) or (params['namespace'] is None):
            raise ValueError("Missing the required parameter `namespace` when calling `notification_settings_entity_update`")
        # verify the required parameter 'entity' is set
        if ('entity' not in params) or (params['entity'] is None):
            raise ValueError("Missing the required parameter `entity` when calling `notification_settings_entity_update`")


        collection_formats = {}

        path_params = {}
        if 'namespace' in params:
            path_params['namespace'] = params['namespace']
        if 'entity' in params:
            path_params['entity'] = params['entity']

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'notification_settings_data' in params:
            body_params = params['notification_settings_data']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json', 'text/html'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['jwt']

        return self.api_client.call_api('/v1/{namespace}/notifications/settings/entity/{entity}', 'PATCH',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type='NotificationSettings',
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def notification_settings_read(self, namespace, **kwargs):
        """
        Retrieve global notification settings for the authenticated user
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.notification_settings_read(namespace, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str namespace: User or team data. (required)
        :return: list[NotificationSettings]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.notification_settings_read_with_http_info(namespace, **kwargs)
        else:
            (data) = self.notification_settings_read_with_http_info(namespace, **kwargs)
            return data

    def notification_settings_read_with_http_info(self, namespace, **kwargs):
        """
        Retrieve global notification settings for the authenticated user
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.notification_settings_read_with_http_info(namespace, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str namespace: User or team data. (required)
        :return: list[NotificationSettings]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['namespace']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method notification_settings_read" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'namespace' is set
        if ('namespace' not in params) or (params['namespace'] is None):
            raise ValueError("Missing the required parameter `namespace` when calling `notification_settings_read`")


        collection_formats = {}

        path_params = {}
        if 'namespace' in params:
            path_params['namespace'] = params['namespace']

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json', 'text/html'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['jwt']

        return self.api_client.call_api('/v1/{namespace}/notifications/settings/', 'GET',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type='list[NotificationSettings]',
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def notification_settings_update(self, namespace, **kwargs):
        """
        Modify global notification settings.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.notification_settings_update(namespace, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str namespace: User or team name. (required)
        :param NotificationSettingsData notification_settings_data:
        :return: NotificationSettings
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.notification_settings_update_with_http_info(namespace, **kwargs)
        else:
            (data) = self.notification_settings_update_with_http_info(namespace, **kwargs)
            return data

    def notification_settings_update_with_http_info(self, namespace, **kwargs):
        """
        Modify global notification settings.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.notification_settings_update_with_http_info(namespace, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str namespace: User or team name. (required)
        :param NotificationSettingsData notification_settings_data:
        :return: NotificationSettings
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['namespace', 'notification_settings_data']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method notification_settings_update" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'namespace' is set
        if ('namespace' not in params) or (params['namespace'] is None):
            raise ValueError("Missing the required parameter `namespace` when calling `notification_settings_update`")


        collection_formats = {}

        path_params = {}
        if 'namespace' in params:
            path_params['namespace'] = params['namespace']

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'notification_settings_data' in params:
            body_params = params['notification_settings_data']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json', 'text/html'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['jwt']

        return self.api_client.call_api('/v1/{namespace}/notifications/settings/', 'PATCH',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type='NotificationSettings',
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def notification_update(self, namespace, notification_id, **kwargs):
        """
        Mark a specific notification as either read or unread.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.notification_update(namespace, notification_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str namespace: User or team data. (required)
        :param str notification_id: Notification UUID. (required)
        :param NotificationUpdateData notification_data:
        :return: Notification
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.notification_update_with_http_info(namespace, notification_id, **kwargs)
        else:
            (data) = self.notification_update_with_http_info(namespace, notification_id, **kwargs)
            return data

    def notification_update_with_http_info(self, namespace, notification_id, **kwargs):
        """
        Mark a specific notification as either read or unread.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.notification_update_with_http_info(namespace, notification_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str namespace: User or team data. (required)
        :param str notification_id: Notification UUID. (required)
        :param NotificationUpdateData notification_data:
        :return: Notification
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['namespace', 'notification_id', 'notification_data']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method notification_update" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'namespace' is set
        if ('namespace' not in params) or (params['namespace'] is None):
            raise ValueError("Missing the required parameter `namespace` when calling `notification_update`")
        # verify the required parameter 'notification_id' is set
        if ('notification_id' not in params) or (params['notification_id'] is None):
            raise ValueError("Missing the required parameter `notification_id` when calling `notification_update`")


        collection_formats = {}

        path_params = {}
        if 'namespace' in params:
            path_params['namespace'] = params['namespace']
        if 'notification_id' in params:
            path_params['notification_id'] = params['notification_id']

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'notification_data' in params:
            body_params = params['notification_data']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json', 'text/html'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['jwt']

        return self.api_client.call_api('/v1/{namespace}/notifications/{notification_id}', 'PATCH',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type='Notification',
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def notifications_list(self, namespace, **kwargs):
        """
        Get notifications of all types and entities for the authenticated user.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.notifications_list(namespace, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str namespace: User or team data. (required)
        :param str limit: Limit when getting items.
        :param str offset: Offset when getting items.
        :param str ordering: Ordering when getting items.
        :param bool read: When true, get only read notifications. When false, get only unread notifications. Default behavior is to return both read and unread.
        :return: list[Notification]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.notifications_list_with_http_info(namespace, **kwargs)
        else:
            (data) = self.notifications_list_with_http_info(namespace, **kwargs)
            return data

    def notifications_list_with_http_info(self, namespace, **kwargs):
        """
        Get notifications of all types and entities for the authenticated user.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.notifications_list_with_http_info(namespace, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str namespace: User or team data. (required)
        :param str limit: Limit when getting items.
        :param str offset: Offset when getting items.
        :param str ordering: Ordering when getting items.
        :param bool read: When true, get only read notifications. When false, get only unread notifications. Default behavior is to return both read and unread.
        :return: list[Notification]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['namespace', 'limit', 'offset', 'ordering', 'read']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method notifications_list" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'namespace' is set
        if ('namespace' not in params) or (params['namespace'] is None):
            raise ValueError("Missing the required parameter `namespace` when calling `notifications_list`")


        collection_formats = {}

        path_params = {}
        if 'namespace' in params:
            path_params['namespace'] = params['namespace']

        query_params = []
        if 'limit' in params:
            query_params.append(('limit', params['limit']))
        if 'offset' in params:
            query_params.append(('offset', params['offset']))
        if 'ordering' in params:
            query_params.append(('ordering', params['ordering']))
        if 'read' in params:
            query_params.append(('read', params['read']))

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json', 'text/html'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['jwt']

        return self.api_client.call_api('/v1/{namespace}/notifications/', 'GET',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type='list[Notification]',
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def notifications_list_entity(self, namespace, entity, **kwargs):
        """
        Get notifications of all types and entities for the authenticated user.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.notifications_list_entity(namespace, entity, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str namespace: User or team data. (required)
        :param str entity: Entity to filter notifications by. (required)
        :param str limit: Limit when getting items.
        :param str offset: Offset when getting items.
        :param str ordering: Ordering when getting items.
        :param bool read: When true, get only read notifications. When false, get only unread notifications. Default behavior is to return both read and unread.
        :return: list[Notification]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.notifications_list_entity_with_http_info(namespace, entity, **kwargs)
        else:
            (data) = self.notifications_list_entity_with_http_info(namespace, entity, **kwargs)
            return data

    def notifications_list_entity_with_http_info(self, namespace, entity, **kwargs):
        """
        Get notifications of all types and entities for the authenticated user.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.notifications_list_entity_with_http_info(namespace, entity, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str namespace: User or team data. (required)
        :param str entity: Entity to filter notifications by. (required)
        :param str limit: Limit when getting items.
        :param str offset: Offset when getting items.
        :param str ordering: Ordering when getting items.
        :param bool read: When true, get only read notifications. When false, get only unread notifications. Default behavior is to return both read and unread.
        :return: list[Notification]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['namespace', 'entity', 'limit', 'offset', 'ordering', 'read']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method notifications_list_entity" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'namespace' is set
        if ('namespace' not in params) or (params['namespace'] is None):
            raise ValueError("Missing the required parameter `namespace` when calling `notifications_list_entity`")
        # verify the required parameter 'entity' is set
        if ('entity' not in params) or (params['entity'] is None):
            raise ValueError("Missing the required parameter `entity` when calling `notifications_list_entity`")


        collection_formats = {}

        path_params = {}
        if 'namespace' in params:
            path_params['namespace'] = params['namespace']
        if 'entity' in params:
            path_params['entity'] = params['entity']

        query_params = []
        if 'limit' in params:
            query_params.append(('limit', params['limit']))
        if 'offset' in params:
            query_params.append(('offset', params['offset']))
        if 'ordering' in params:
            query_params.append(('ordering', params['ordering']))
        if 'read' in params:
            query_params.append(('read', params['read']))

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json', 'text/html'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['jwt']

        return self.api_client.call_api('/v1/{namespace}/notifications/entity/{entity}', 'GET',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type='list[Notification]',
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def notifications_update_entity_list(self, namespace, entity, notification_data, **kwargs):
        """
        Mark a list of notifications as either read or unread.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.notifications_update_entity_list(namespace, entity, notification_data, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str namespace: User or team name. (required)
        :param str entity: Entity to filter notifications by. (required)
        :param NotificationListUpdateData notification_data: (required)
        :return: Notification
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.notifications_update_entity_list_with_http_info(namespace, entity, notification_data, **kwargs)
        else:
            (data) = self.notifications_update_entity_list_with_http_info(namespace, entity, notification_data, **kwargs)
            return data

    def notifications_update_entity_list_with_http_info(self, namespace, entity, notification_data, **kwargs):
        """
        Mark a list of notifications as either read or unread.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.notifications_update_entity_list_with_http_info(namespace, entity, notification_data, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str namespace: User or team name. (required)
        :param str entity: Entity to filter notifications by. (required)
        :param NotificationListUpdateData notification_data: (required)
        :return: Notification
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['namespace', 'entity', 'notification_data']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method notifications_update_entity_list" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'namespace' is set
        if ('namespace' not in params) or (params['namespace'] is None):
            raise ValueError("Missing the required parameter `namespace` when calling `notifications_update_entity_list`")
        # verify the required parameter 'entity' is set
        if ('entity' not in params) or (params['entity'] is None):
            raise ValueError("Missing the required parameter `entity` when calling `notifications_update_entity_list`")
        # verify the required parameter 'notification_data' is set
        if ('notification_data' not in params) or (params['notification_data'] is None):
            raise ValueError("Missing the required parameter `notification_data` when calling `notifications_update_entity_list`")


        collection_formats = {}

        path_params = {}
        if 'namespace' in params:
            path_params['namespace'] = params['namespace']
        if 'entity' in params:
            path_params['entity'] = params['entity']

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'notification_data' in params:
            body_params = params['notification_data']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json', 'text/html'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['jwt']

        return self.api_client.call_api('/v1/{namespace}/notifications/entity/{entity}', 'PATCH',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type='Notification',
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def notifications_update_list(self, namespace, notification_data, **kwargs):
        """
        Mark a list of notifications as either read or unread.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.notifications_update_list(namespace, notification_data, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str namespace: User or team name. (required)
        :param NotificationListUpdateData notification_data: (required)
        :return: Notification
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.notifications_update_list_with_http_info(namespace, notification_data, **kwargs)
        else:
            (data) = self.notifications_update_list_with_http_info(namespace, notification_data, **kwargs)
            return data

    def notifications_update_list_with_http_info(self, namespace, notification_data, **kwargs):
        """
        Mark a list of notifications as either read or unread.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.notifications_update_list_with_http_info(namespace, notification_data, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str namespace: User or team name. (required)
        :param NotificationListUpdateData notification_data: (required)
        :return: Notification
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['namespace', 'notification_data']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method notifications_update_list" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'namespace' is set
        if ('namespace' not in params) or (params['namespace'] is None):
            raise ValueError("Missing the required parameter `namespace` when calling `notifications_update_list`")
        # verify the required parameter 'notification_data' is set
        if ('notification_data' not in params) or (params['notification_data'] is None):
            raise ValueError("Missing the required parameter `notification_data` when calling `notifications_update_list`")


        collection_formats = {}

        path_params = {}
        if 'namespace' in params:
            path_params['namespace'] = params['namespace']

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'notification_data' in params:
            body_params = params['notification_data']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json', 'text/html'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['jwt']

        return self.api_client.call_api('/v1/{namespace}/notifications/', 'PATCH',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type='Notification',
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)



# coding: utf-8

"""
    3blades API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class ServerConfig(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'type': 'str',
        'script': 'str',
        'function': 'str',
        'command': 'str'
    }

    attribute_map = {
        'type': 'type',
        'script': 'script',
        'function': 'function',
        'command': 'command'
    }

    def __init__(self, type=None, script=None, function=None, command=None):
        """
        ServerConfig - a model defined in Swagger
        """

        self._type = None
        self._script = None
        self._function = None
        self._command = None

        if type is not None:
          self.type = type
        if script is not None:
          self.script = script
        if function is not None:
          self.function = function
        if command is not None:
          self.command = command

    @property
    def type(self):
        """
        Gets the type of this ServerConfig.
        Server type.

        :return: The type of this ServerConfig.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """
        Sets the type of this ServerConfig.
        Server type.

        :param type: The type of this ServerConfig.
        :type: str
        """
        allowed_values = ["jupyter", "restful", "cron"]
        if type not in allowed_values:
            raise ValueError(
                "Invalid value for `type` ({0}), must be one of {1}"
                .format(type, allowed_values)
            )

        self._type = type

    @property
    def script(self):
        """
        Gets the script of this ServerConfig.
        Server script file.

        :return: The script of this ServerConfig.
        :rtype: str
        """
        return self._script

    @script.setter
    def script(self, script):
        """
        Sets the script of this ServerConfig.
        Server script file.

        :param script: The script of this ServerConfig.
        :type: str
        """

        self._script = script

    @property
    def function(self):
        """
        Gets the function of this ServerConfig.
        Server function.

        :return: The function of this ServerConfig.
        :rtype: str
        """
        return self._function

    @function.setter
    def function(self, function):
        """
        Sets the function of this ServerConfig.
        Server function.

        :param function: The function of this ServerConfig.
        :type: str
        """

        self._function = function

    @property
    def command(self):
        """
        Gets the command of this ServerConfig.
        Command to run

        :return: The command of this ServerConfig.
        :rtype: str
        """
        return self._command

    @command.setter
    def command(self, command):
        """
        Sets the command of this ServerConfig.
        Command to run

        :param command: The command of this ServerConfig.
        :type: str
        """

        self._command = command

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, ServerConfig):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    3blades API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import os
import sys
import unittest

import swagger_client
from swagger_client.rest import ApiException
from swagger_client.apis.billing_api import BillingApi


class TestBillingApi(unittest.TestCase):
    """ BillingApi unit test stubs """

    def setUp(self):
        self.api = swagger_client.apis.billing_api.BillingApi()

    def tearDown(self):
        pass

    def test_billing_cards_create(self):
        """
        Test case for billing_cards_create

        Create new credit card
        """
        pass

    def test_billing_cards_delete(self):
        """
        Test case for billing_cards_delete

        Delete a credit card
        """
        pass

    def test_billing_cards_list(self):
        """
        Test case for billing_cards_list

        Get credit cards
        """
        pass

    def test_billing_cards_read(self):
        """
        Test case for billing_cards_read

        Get credit card by id
        """
        pass

    def test_billing_cards_replace(self):
        """
        Test case for billing_cards_replace

        Replace a credit card
        """
        pass

    def test_billing_cards_update(self):
        """
        Test case for billing_cards_update

        Update a credit card
        """
        pass

    def test_billing_invoice_items_list(self):
        """
        Test case for billing_invoice_items_list

        Get invoice items for a given invoice.
        """
        pass

    def test_billing_invoice_items_read(self):
        """
        Test case for billing_invoice_items_read

        Get a specific InvoiceItem.
        """
        pass

    def test_billing_invoices_list(self):
        """
        Test case for billing_invoices_list

        Get invoices
        """
        pass

    def test_billing_invoices_read(self):
        """
        Test case for billing_invoices_read

        Get an invoice
        """
        pass

    def test_billing_plans_list(self):
        """
        Test case for billing_plans_list

        Get billing plans
        """
        pass

    def test_billing_plans_read(self):
        """
        Test case for billing_plans_read

        Get a billing plan
        """
        pass

    def test_billing_subscriptions_create(self):
        """
        Test case for billing_subscriptions_create

        Create a new subscription
        """
        pass

    def test_billing_subscriptions_delete(self):
        """
        Test case for billing_subscriptions_delete

        Delete a subscription
        """
        pass

    def test_billing_subscriptions_list(self):
        """
        Test case for billing_subscriptions_list

        Get active subscriptons
        """
        pass

    def test_billing_subscriptions_read(self):
        """
        Test case for billing_subscriptions_read

        Get a subscriptions
        """
        pass


if __name__ == '__main__':
    unittest.main()
